import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Tag, Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
import { l } from 'node_modules/vite/dist/node/types.d-aGj9QkWt';
// 引入开关组件
type CheckedType = boolean | string | number;

export const columns: BasicColumn[] = [
  {
    title: '主题域名称',
    dataIndex: 'themeName',
    width: 150,
    // onEditRow:true
  },
  {
    title: '英文名称',
    dataIndex: 'themeEngName',
    width: 150,
    // onEditRow:true
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 150,
    customRender: (text) => text || '-',
    // onEditRow:true
  },
  {
    title: '创建人',
    dataIndex: 'creator',
    width: 150,
    // onEditRow:true
  },
  {
    title: '创建时间',
    dataIndex: 'createTime',
    width: 150,
    // onEditRow:true
  },
  {
    title: '更新时间',
    dataIndex: 'updateTime',
    width: 150,
    // onEditRow:true
  },
];
export const searchFormSchema: FormSchema[] = [
  {
    field: 'name',
    label: ' ',
    component: 'Input',
    componentProps: {
      placeholder: '请输入主题域名称/英文名称',
    },
    colProps: { span: 5 },
  },
];
export const physicalModelFormSchema: any[] = [
  {
    field: 'themeName',
    label: '主题域名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'themeEngName',
    label: '英文名称',
    component: 'Input',
    required: true,
    colProps: { span: 24 },
  },
  {
    field: 'description',
    label: '描述',
    component: 'InputTextArea',
    required: false,
    colProps: { span: 24 },
  },
  {
    field: 'themeFather',
    label: '父级主题域',
    colProps: { span: 24 },
    component: 'TreeSelect',
    componentProps: {
      fieldNames: {
        label: 'label',
        value: 'value',
      },
      treeData: [
        {
          label: '一级主题域1',
          value: 'option1',
          children: [
            {
              label: '二级主题域1',
              value: 'subOption1-1',
            },
            {
              label: '二级主题域2',
              value: 'subOption1-2',
            },
          ],
        },
        {
          label: '一级主题域2',
          value: 'option2',
          children: [
            {
              label: '二级主题域3',
              value: 'subOption2-1',
            },
            {
              label: '二级主题域4',
              value: 'subOption2-2',
            },
          ],
        },
      ],
    },
  },
];

/**移动*/
export const MoveFormSchema: any[] = [
  {
    field: 'institutionId',
    label: '所属机构',
    component: 'TreeSelect',
    colProps: { lg: 24, md: 24 },
    componentProps: {
      fieldNames: {
        label: 'institutionName',
        value: 'businessId',
      },
      getPopupContainer: () => document.body,
    },
    required: true,
  },
];
export const TreeData: any[] = [
  {
    delFlag: '0',
    flag: '1',
    businessId: 100,
    modelName: '主题域',
    parentId: 0,
    'code:': '001',
    ancestors: '0',
    orderNum: 0,
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    type: 'MySQL',
    // icon: 'ion:settings-outline',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 101,
    modelName: '一级主题域1',
    parentId: 100,
    'code:': '002',
    ancestors: '0,100',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 102,
    modelName: '一级主题域1',
    parentId: 100,
    'code:': '002',
    ancestors: '0,100',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 103,
    modelName: '一级主题域2',
    parentId: 100,
    'code:': '002',
    ancestors: '0,100',
    orderNum: 1,
    type: 'DB2',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:folder-open-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 201,
    modelName: '二级主题域1',
    parentId: 101,
    'code:': '002',
    ancestors: '0,100，101',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 202,
    modelName: '二级主题域2',
    parentId: 101,
    'code:': '002',
    ancestors: '0,100，101',
    orderNum: 1,
    type: 'ArgoDB',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 203,
    modelName: '二级主题域3',
    parentId: 102,
    'code:': '002',
    ancestors: '0,100，102',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 204,
    modelName: '二级主题域4',
    parentId: 102,
    'code:': '002',
    ancestors: '0,100，102',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:codepen-outlined',
  },
  {
    delFlag: '0',
    flag: '1',
    businessId: 205,
    modelName: '二级主题域5',
    parentId: 103,
    'code:': '002',
    ancestors: '0,100，103',
    orderNum: 1,
    type: 'MySQL',
    holder: 'admin',
    createDate: '2024-10-24 10:04:04',
    updateDate: '2024-10-24 10:04:04',
    // icon: 'ant-design:codepen-outlined',
  },
];
export const detailColumns: BasicColumn[] = [
  {
    title: '属性名称',
    dataIndex: 'name',
    width: 150,
  },
  {
    title: '描述',
    dataIndex: 'description',
    width: 150,
  },
  {
    title: '属性英文名',
    dataIndex: 'englishName',
    width: 150,
  },
  {
    title: '是否必填',
    dataIndex: 'isWrite',
    width: 150,
    customRender: ({ record }) => (record.isWrite === '1' ? '是' : '否'),
  },
  {
    title: '是否显示',
    dataIndex: 'isShow',
    width: 150,
    customRender: ({ record }) => (record.isShow === '1' ? '是' : '否'),
  },
  {
    title: '类型',
    dataIndex: 'type',
    width: 200,
    customRender: ({ record }) => {
      const typeMap = {
        '1': '字符串',
        '2': '布尔',
        '3': '整型',
        '4': '浮点型',
      };
      return typeMap[record.type];
    },
  },
];
